Index: mips/atheros/ar71xx_spi.c
===================================================================
--- mips/atheros/ar71xx_spi.c	(revision 215172)
+++ mips/atheros/ar71xx_spi.c	(working copy)
@@ -83,6 +83,7 @@
 static int
 ar71xx_spi_probe(device_t dev)
 {
+
 	device_set_desc(dev, "AR71XX SPI");
 	return (0);
 }
@@ -102,11 +103,10 @@
 		return (ENXIO);
 	}
 
-
 	SPI_WRITE(sc, AR71XX_SPI_FS, 1);
-	sc->sc_reg_ctrl  = SPI_READ(sc, AR71XX_SPI_CTRL);
+	sc->sc_reg_ctrl = SPI_READ(sc, AR71XX_SPI_CTRL);
 	SPI_WRITE(sc, AR71XX_SPI_CTRL, 0x43);
-	SPI_WRITE(sc, AR71XX_SPI_IO_CTRL, SPI_IO_CTRL_CSMASK);
+	SPI_WRITE(sc, AR71XX_SPI_IO_CTRL, SPI_IO_CTRL_CS(0));
 
 	device_add_child(dev, "spibus", 0);
 	return (bus_generic_attach(dev));
@@ -115,34 +115,37 @@
 static void
 ar71xx_spi_chip_activate(struct ar71xx_spi_softc *sc, int cs)
 {
-	uint32_t ioctrl = SPI_IO_CTRL_CSMASK;
+
 	/*
-	 * Put respective CSx to low
+	 * Activate the respective device (we have three CS pins allowing
+	 * 7 muxed devices on bus).
+	 * At any given moment only one device should be selected on bus. 
+	 * if cs is set to 0 it will be the same as SPI_IO_CTRL_CSMASK
+	 * (0x7 - all pins high - no device selected).
 	 */
-	ioctrl &= ~(SPI_IO_CTRL_CS0 << cs);
-
-	SPI_WRITE(sc, AR71XX_SPI_IO_CTRL, ioctrl);
+	SPI_WRITE(sc, AR71XX_SPI_IO_CTRL, SPI_IO_CTRL_CS(cs));
 }
 
 static void
 ar71xx_spi_chip_deactivate(struct ar71xx_spi_softc *sc, int cs)
 {
+
 	/*
-	 * Put all CSx to high
+	 * Deactivate all devices, put all CSx to high
 	 */
-	SPI_WRITE(sc, AR71XX_SPI_IO_CTRL, SPI_IO_CTRL_CSMASK);
+	SPI_WRITE(sc, AR71XX_SPI_IO_CTRL, SPI_IO_CTRL_CS(0));
 }
 
 static uint8_t
 ar71xx_spi_txrx(struct ar71xx_spi_softc *sc, int cs, uint8_t data)
 {
 	int bit;
-	/* CS0 */
-	uint32_t ioctrl = SPI_IO_CTRL_CSMASK;
+	uint32_t ioctrl;
+
 	/*
-	 * low-level for selected CS
+	 * activate the selected CS
 	 */
-	ioctrl &= ~(SPI_IO_CTRL_CS0 << cs);
+	ioctrl = SPI_IO_CTRL_CS(cs);
 
 	uint32_t iod, rds;
 	for (bit = 7; bit >=0; bit--) {
Index: mips/atheros/ar71xxreg.h
===================================================================
--- mips/atheros/ar71xxreg.h	(revision 215172)
+++ mips/atheros/ar71xxreg.h	(working copy)
@@ -480,7 +480,7 @@
 #define			SPI_IO_CTRL_CS2			(1 << 18)
 #define			SPI_IO_CTRL_CS1			(1 << 17)
 #define			SPI_IO_CTRL_CS0			(1 << 16)
-#define			SPI_IO_CTRL_CSMASK		(7 << 16)
+#define			SPI_IO_CTRL_CS(cs)		((7 - cs) << 16)
 #define			SPI_IO_CTRL_CLK			(1 << 8)
 #define			SPI_IO_CTRL_DO			1
 #define		AR71XX_SPI_RDS		0x0C
